# twisted-telegram-bot
Asynchronous Twisted-based Telegram Bot API for Python

[![Build Status](https://travis-ci.org/unintended/twisted-telegram-bot.svg?branch=master)](https://travis-ci.org/unintended/twisted-telegram-bot)

Based on the idea and structure of [pyTelegramBotAPI](https://github.com/eternnoir/pyTelegramBotAPI/)